use crate::{schema, UIDCError};
use microrm::prelude::*;

pub fn create(realm: &schema::Realm, name: &String) -> Result<(), UIDCError> {
    realm.clients.insert(schema::Client {
        shortname: name.into(),
        secret: "".into(),
        redirects: Default::default(),
        scopes: Default::default(),
    })?;
    Ok(())
}

pub fn inspect(realm: &schema::Realm, name: &String) -> Result<(), UIDCError> {
    if let Some(client) = realm.clients.unique(name).get()? {
        println!("Found client {name}");
        println!("Valid redirect URIs:");
        for redirect in client.redirects.get()? {
            println!(" - {}", redirect.redirect);
        }

        println!("Valid scopes:");
        for scope in client.scopes.get()? {
            println!(" - {}", scope.shortname);
        }
    }
    else {
        println!("No such client {name}");
    }

    Ok(())
}
